@@ -27,62 +27,20 @@ pub use ndjson::*;
 #[cfg(feature = "parquet")]
 pub use parquet::*;
 use polars_arrow::prelude::QuantileInterpolOptions;
-#[cfg(any(feature = "parquet", feature = "csv-file", feature = "ipc"))]
-use polars_core::datatypes::PlHashMap;
 use polars_core::frame::explode::MeltArgs;
 use polars_core::frame::hash_join::JoinType;
 use polars_core::prelude::*;
 use polars_io::RowCount;
-#[cfg(feature = "serde")]
-use serde::{Deserialize, Serialize};
+pub use polars_plan::frame::{AllowedOptimizations, OptState};
+use polars_plan::global::FETCH_ROWS;
+#[cfg(any(feature = "ipc", feature = "parquet", feature = "csv-file"))]
+use polars_plan::logical_plan::collect_fingerprints;
+use polars_plan::logical_plan::optimize;
+use polars_plan::utils::{combine_predicates_expr, expr_to_leaf_column_names};
 
-use crate::logical_plan::optimizer::aggregate_pushdown::AggregatePushdown;
-#[cfg(any(
-    feature = "parquet",
-    feature = "csv-file",
-    feature = "ipc",
-    feature = "cse"
-))]
-use crate::logical_plan::optimizer::file_caching::FileCacher;
-use crate::logical_plan::optimizer::predicate_pushdown::PredicatePushDown;
-use crate::logical_plan::optimizer::projection_pushdown::ProjectionPushDown;
-use crate::logical_plan::optimizer::simplify_expr::SimplifyExprRule;
-use crate::logical_plan::optimizer::stack_opt::{OptimizationRule, StackOptimizer};
-use crate::logical_plan::FETCH_ROWS;
+use crate::physical_plan::executors::Executor;
 use crate::physical_plan::state::ExecutionState;
-use crate::prelude::delay_rechunk::DelayRechunk;
-use crate::prelude::drop_nulls::ReplaceDropNulls;
-use crate::prelude::fast_projection::FastProjectionAndCollapse;
-#[cfg(any(feature = "ipc", feature = "parquet", feature = "csv-file"))]
-use crate::prelude::file_caching::collect_fingerprints;
-#[cfg(any(feature = "ipc", feature = "parquet", feature = "csv-file"))]
-use crate::prelude::file_caching::find_column_union_and_fingerprints;
-use crate::prelude::simplify_expr::SimplifyBooleanRule;
-use crate::prelude::slice_pushdown_lp::SlicePushDown;
 use crate::prelude::*;
-use crate::utils::{combine_predicates_expr, expr_to_leaf_column_names};
-
-#[derive(Clone, Debug, PartialEq, Eq)]
-#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
-pub struct JoinOptions {
-    pub allow_parallel: bool,
-    pub force_parallel: bool,
-    pub how: JoinType,
-    pub suffix: Cow<'static, str>,
-    pub slice: Option<(i64, usize)>,
-}
-
-impl Default for JoinOptions {
-    fn default() -> Self {
-        JoinOptions {
-            allow_parallel: true,
-            force_parallel: false,
-            how: JoinType::Left,
-            suffix: "_right".into(),
-            slice: None,
-        }
-    }
-}
 
 pub trait IntoLazy {
     fn lazy(self) -> LazyFrame;
@@ -121,40 +79,6 @@ impl From<LogicalPlan> for LazyFrame {
     }
 }
 
-#[derive(Copy, Clone)]
-/// State of the allowed optimizations
-pub struct OptState {
-    pub projection_pushdown: bool,
-    pub predicate_pushdown: bool,
-    pub type_coercion: bool,
-    pub simplify_expr: bool,
-    pub file_caching: bool,
-    pub aggregate_pushdown: bool,
-    pub slice_pushdown: bool,
-    #[cfg(feature = "cse")]
-    pub common_subplan_elimination: bool,
-}
-
-impl Default for OptState {
-    fn default() -> Self {
-        OptState {
-            projection_pushdown: true,
-            predicate_pushdown: true,
-            type_coercion: true,
-            simplify_expr: true,
-            slice_pushdown: true,
-            // will be toggled by a scan operation such as csv scan or parquet scan
-            file_caching: false,
-            aggregate_pushdown: false,
-            #[cfg(feature = "cse")]
-            common_subplan_elimination: true,
-        }
-    }
-}
-
-/// AllowedOptimizations
-pub type AllowedOptimizations = OptState;
-
 impl LazyFrame {
     /// Get a hold on the schema of the current LazyFrame computation.
     pub fn schema(&self) -> PolarsResult<SchemaRef> {
@@ -428,15 +352,23 @@ impl LazyFrame {
         .map(
             move |mut df: DataFrame| {
                 let cols = df.get_columns_mut();
+                let mut removed_count = 0;
                 for (existing, new) in existing.iter().zip(new.iter()) {
-                    let idx_a = cols
-                        .iter()
-                        .position(|s| s.name() == existing.as_str())
-                        .unwrap();
-                    let idx_b = cols.iter().position(|s| s.name() == new.as_str()).unwrap();
-                    cols.swap(idx_a, idx_b);
+                    let idx_a = cols.iter().position(|s| s.name() == existing.as_str());
+                    let idx_b = cols.iter().position(|s| s.name() == new.as_str());
+
+                    match (idx_a, idx_b) {
+                        (Some(idx_a), Some(idx_b)) => {
+                            cols.swap(idx_a, idx_b);
+                        }
+                        // renamed columns are removed by predicate pushdown
+                        _ => {
+                            removed_count += 1;
+                            continue;
+                        }
+                    }
                 }
-                cols.truncate(cols.len() - existing.len());
+                cols.truncate(cols.len() - (existing.len() - removed_count));
                 Ok(df)
             },
             None,
@@ -563,155 +495,7 @@ impl LazyFrame {
         lp_arena: &mut Arena<ALogicalPlan>,
         expr_arena: &mut Arena<AExpr>,
     ) -> PolarsResult<Node> {
-        // get toggle values
-        let predicate_pushdown = self.opt_state.predicate_pushdown;
-        let projection_pushdown = self.opt_state.projection_pushdown;
-        let type_coercion = self.opt_state.type_coercion;
-        let simplify_expr = self.opt_state.simplify_expr;
-        let slice_pushdown = self.opt_state.slice_pushdown;
-        #[cfg(feature = "cse")]
-        let cse = self.opt_state.common_subplan_elimination;
-
-        let agg_scan_projection = self.opt_state.file_caching;
-        let aggregate_pushdown = self.opt_state.aggregate_pushdown;
-
-        let logical_plan = self.get_plan_builder().build();
-        let mut scratch = vec![];
-
-        // gradually fill the rules passed to the optimizer
-        let opt = StackOptimizer {};
-        let mut rules: Vec<Box<dyn OptimizationRule>> = Vec::with_capacity(8);
-
-        // during debug we check if the optimizations have not modified the final schema
-        #[cfg(debug_assertions)]
-        let prev_schema = logical_plan.schema()?.into_owned();
-
-        let mut lp_top = to_alp(logical_plan, expr_arena, lp_arena)?;
-
-        #[cfg(feature = "cse")]
-        let cse_changed = if cse {
-            let (lp, changed) = cse::elim_cmn_subplans(lp_top, lp_arena, expr_arena);
-            lp_top = lp;
-            changed
-        } else {
-            false
-        };
-        #[cfg(not(feature = "cse"))]
-        let cse_changed = false;
-
-        // we do simplification
-        if simplify_expr {
-            rules.push(Box::new(SimplifyExprRule {}));
-        }
-
-        // should be run before predicate pushdown
-        if projection_pushdown {
-            let projection_pushdown_opt = ProjectionPushDown {};
-            let alp = lp_arena.take(lp_top);
-            let alp = projection_pushdown_opt.optimize(alp, lp_arena, expr_arena)?;
-            lp_arena.replace(lp_top, alp);
-            cache_states::set_cache_states(lp_top, lp_arena, expr_arena, &mut scratch, cse_changed);
-        }
-
-        if predicate_pushdown {
-            let predicate_pushdown_opt = PredicatePushDown::default();
-            let alp = lp_arena.take(lp_top);
-            let alp = predicate_pushdown_opt.optimize(alp, lp_arena, expr_arena)?;
-            lp_arena.replace(lp_top, alp);
-        }
-
-        // make sure its before slice pushdown.
-        if projection_pushdown {
-            rules.push(Box::new(FastProjectionAndCollapse {}));
-        }
-        rules.push(Box::new(DelayRechunk {}));
-
-        if slice_pushdown {
-            let slice_pushdown_opt = SlicePushDown {};
-            let alp = lp_arena.take(lp_top);
-            let alp = slice_pushdown_opt.optimize(alp, lp_arena, expr_arena)?;
-
-            lp_arena.replace(lp_top, alp);
-
-            // expressions use the stack optimizer
-            rules.push(Box::new(slice_pushdown_opt));
-        }
-        if type_coercion {
-            rules.push(Box::new(TypeCoercionRule {}))
-        }
-        // this optimization removes branches, so we must do it when type coercion
-        // is completed
-        if simplify_expr {
-            rules.push(Box::new(SimplifyBooleanRule {}));
-        }
-
-        if aggregate_pushdown {
-            rules.push(Box::new(AggregatePushdown::new()))
-        }
-
-        // make sure that we do that once slice pushdown
-        // and predicate pushdown are done. At that moment
-        // the file fingerprints are finished.
-        #[cfg(any(
-            feature = "cse",
-            feature = "parquet",
-            feature = "ipc",
-            feature = "csv-file"
-        ))]
-        if agg_scan_projection || cse_changed {
-            // we do this so that expressions are simplified created by the pushdown optimizations
-            // we must clean up the predicates, because the agg_scan_projection
-            // uses them in the hashtable to determine duplicates.
-            let simplify_bools =
-                &mut [Box::new(SimplifyBooleanRule {}) as Box<dyn OptimizationRule>];
-            lp_top = opt.optimize_loop(simplify_bools, expr_arena, lp_arena, lp_top);
-
-            // scan the LP to aggregate all the column used in scans
-            // these columns will be added to the state of the AggScanProjection rule
-            let mut file_predicate_to_columns_and_count = PlHashMap::with_capacity(32);
-            find_column_union_and_fingerprints(
-                lp_top,
-                &mut file_predicate_to_columns_and_count,
-                lp_arena,
-                expr_arena,
-            );
-
-            let mut file_cacher = FileCacher::new(file_predicate_to_columns_and_count);
-            file_cacher.assign_unions(lp_top, lp_arena, expr_arena, &mut scratch, false);
-            scratch.clear();
-
-            #[cfg(feature = "cse")]
-            if cse_changed {
-                // this must run after cse
-                cse::decrement_file_counters_by_cache_hits(
-                    lp_top,
-                    lp_arena,
-                    expr_arena,
-                    0,
-                    &mut scratch,
-                );
-            }
-        }
-
-        rules.push(Box::new(ReplaceDropNulls {}));
-
-        lp_top = opt.optimize_loop(&mut rules, expr_arena, lp_arena, lp_top);
-
-        // during debug we check if the optimizations have not modified the final schema
-        #[cfg(debug_assertions)]
-        {
-            // only check by names because we may supercast types.
-            assert_eq!(
-                prev_schema.iter_names().collect::<Vec<_>>(),
-                lp_arena
-                    .get(lp_top)
-                    .schema(lp_arena)
-                    .iter_names()
-                    .collect::<Vec<_>>()
-            );
-        };
-
-        Ok(lp_top)
+        optimize(self.logical_plan, self.opt_state, lp_arena, expr_arena)
     }
 
     fn prepare_collect(self) -> PolarsResult<(ExecutionState, Box<dyn Executor>)> {
@@ -872,13 +656,27 @@ impl LazyFrame {
             .map(|e| e.clone().into())
             .collect::<Vec<_>>();
         let opt_state = self.get_opt_state();
-        LazyGroupBy {
-            logical_plan: self.logical_plan,
-            opt_state,
-            keys,
-            maintain_order: false,
-            dynamic_options: None,
-            rolling_options: None,
+
+        #[cfg(feature = "dynamic_groupby")]
+        {
+            LazyGroupBy {
+                logical_plan: self.logical_plan,
+                opt_state,
+                keys,
+                maintain_order: false,
+                dynamic_options: None,
+                rolling_options: None,
+            }
+        }
+
+        #[cfg(not(feature = "dynamic_groupby"))]
+        {
+            LazyGroupBy {
+                logical_plan: self.logical_plan,
+                opt_state,
+                keys,
+                maintain_order: false,
+            }
         }
     }
 
@@ -889,6 +687,8 @@ impl LazyFrame {
     /// Different from a [`dynamic_groupby`] the windows are now determined by the
     /// individual values and are not of constant intervals. For constant intervals use
     /// *groupby_dynamic*
+    #[cfg(feature = "dynamic_groupby")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "dynamic_groupby")))]
     pub fn groupby_rolling<E: AsRef<[Expr]>>(
         self,
         by: E,
@@ -920,6 +720,8 @@ impl LazyFrame {
     ///
     /// The `by` argument should be empty `[]` if you don't want to combine this
     /// with a ordinary groupby on these keys.
+    #[cfg(feature = "dynamic_groupby")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "dynamic_groupby")))]
     pub fn groupby_dynamic<E: AsRef<[Expr]>>(
         self,
         by: E,
@@ -944,13 +746,27 @@ impl LazyFrame {
             .map(|e| e.clone().into())
             .collect::<Vec<_>>();
         let opt_state = self.get_opt_state();
-        LazyGroupBy {
-            logical_plan: self.logical_plan,
-            opt_state,
-            keys,
-            maintain_order: true,
-            dynamic_options: None,
-            rolling_options: None,
+
+        #[cfg(feature = "dynamic_groupby")]
+        {
+            LazyGroupBy {
+                logical_plan: self.logical_plan,
+                opt_state,
+                keys,
+                maintain_order: true,
+                dynamic_options: None,
+                rolling_options: None,
+            }
+        }
+
+        #[cfg(not(feature = "dynamic_groupby"))]
+        {
+            LazyGroupBy {
+                logical_plan: self.logical_plan,
+                opt_state,
+                keys,
+                maintain_order: true,
+            }
         }
     }
 
@@ -1371,7 +1187,17 @@ impl LazyFrame {
         };
         self.map(
             move |df| df.unnest(&cols2),
-            Some(AllowedOptimizations::default()),
+            Some(AllowedOptimizations {
+                projection_pushdown: false,
+                predicate_pushdown: true,
+                type_coercion: true,
+                simplify_expr: true,
+                file_caching: true,
+                aggregate_pushdown: true,
+                slice_pushdown: true,
+                #[cfg(feature = "cse")]
+                common_subplan_elimination: true,
+            }),
             Some(Arc::new(udf_schema)),
             Some("unnest"),
         )
@@ -1385,7 +1211,9 @@ pub struct LazyGroupBy {
     opt_state: OptState,
     keys: Vec<Expr>,
     maintain_order: bool,
+    #[cfg(feature = "dynamic_groupby")]
     dynamic_options: Option<DynamicGroupOptions>,
+    #[cfg(feature = "dynamic_groupby")]
     rolling_options: Option<RollingGroupOptions>,
 }
 
@@ -1413,6 +1241,7 @@ impl LazyGroupBy {
     /// }
     /// ```
     pub fn agg<E: AsRef<[Expr]>>(self, aggs: E) -> LazyFrame {
+        #[cfg(feature = "dynamic_groupby")]
         let lp = LogicalPlanBuilder::from(self.logical_plan)
             .groupby(
                 Arc::new(self.keys),
@@ -1423,6 +1252,11 @@ impl LazyGroupBy {
                 self.rolling_options,
             )
             .build();
+
+        #[cfg(not(feature = "dynamic_groupby"))]
+        let lp = LogicalPlanBuilder::from(self.logical_plan)
+            .groupby(Arc::new(self.keys), aggs, None, self.maintain_order)
+            .build();
         LazyFrame::from_logical_plan(lp, self.opt_state)
     }
 
@@ -1456,6 +1290,16 @@ impl LazyGroupBy {
     where
         F: 'static + Fn(DataFrame) -> PolarsResult<DataFrame> + Send + Sync,
     {
+        #[cfg(feature = "dynamic_groupby")]
+        let options = GroupbyOptions {
+            dynamic: None,
+            rolling: None,
+            slice: None,
+        };
+
+        #[cfg(not(feature = "dynamic_groupby"))]
+        let options = GroupbyOptions { slice: None };
+
         let lp = LogicalPlan::Aggregate {
             input: Box::new(self.logical_plan),
             keys: Arc::new(self.keys),
@@ -1463,11 +1307,7 @@ impl LazyGroupBy {
             schema,
             apply: Some(Arc::new(f)),
             maintain_order: self.maintain_order,
-            options: GroupbyOptions {
-                dynamic: None,
-                rolling: None,
-                slice: None,
-            },
+            options,
         };
         LazyFrame::from_logical_plan(lp, self.opt_state)
     }
