@@ -10,7 +10,7 @@ use polars_core::series::IsSorted;
 use polars_core::POOL;
 use polars_utils::sort::perfect_sort;
 
-use crate::logical_plan::Context;
+use super::*;
 use crate::physical_plan::state::ExecutionState;
 use crate::prelude::*;
 
@@ -255,7 +255,7 @@ impl PhysicalExpr for WindowExpr {
                 cache_key.push_str(s.name());
             }
 
-            let mut gt_map = state.group_tuples.lock();
+            let mut gt_map = state.group_tuples.lock().unwrap();
             // we run sequential and partitioned
             // and every partition run the cache should be empty so we expect a max of 1.
             debug_assert!(gt_map.len() <= 1);
@@ -291,7 +291,7 @@ impl PhysicalExpr for WindowExpr {
         let cache_gb = |gb: GroupBy| {
             if state.cache_window() {
                 let groups = gb.take_groups();
-                let mut gt_map = state.group_tuples.lock();
+                let mut gt_map = state.group_tuples.lock().unwrap();
                 gt_map.insert(cache_key.clone(), groups);
             } else {
                 // drop the group tuples to reduce allocated memory.
@@ -449,7 +449,7 @@ impl PhysicalExpr for WindowExpr {
 
                 // try to get cached join_tuples
                 let join_opt_ids = if state.cache_window() {
-                    let mut jt_map = state.join_tuples.lock();
+                    let mut jt_map = state.join_tuples.lock().unwrap();
                     // we run sequential and partitioned
                     // and every partition run the cache should be empty so we expect a max of 1.
                     debug_assert!(jt_map.len() <= 1);
@@ -469,7 +469,7 @@ impl PhysicalExpr for WindowExpr {
                 }
 
                 if state.cache_window() {
-                    let mut jt_map = state.join_tuples.lock();
+                    let mut jt_map = state.join_tuples.lock().unwrap();
                     jt_map.insert(cache_key, join_opt_ids);
                 }
 
