@@ -1,8 +1,9 @@
 use polars_core::prelude::*;
 use polars_io::aggregations::ScanAggregation;
 
-use super::super::executors;
-use crate::prelude::*;
+use super::super::executors::{self, Executor};
+use super::*;
+use crate::utils::*;
 
 #[cfg(any(feature = "ipc", feature = "parquet", feature = "csv-file"))]
 fn aggregate_expr_to_scan_agg(
@@ -19,11 +20,17 @@ fn aggregate_expr_to_scan_agg(
             };
             if let AExpr::Agg(agg) = expr_arena.get(expr) {
                 match agg {
-                    AAggExpr::Min(e) => ScanAggregation::Min {
+                    AAggExpr::Min {
+                        input: e,
+                        propagate_nans: false,
+                    } => ScanAggregation::Min {
                         column: (*aexpr_to_leaf_names(*e, expr_arena).pop().unwrap()).to_string(),
                         alias,
                     },
-                    AAggExpr::Max(e) => ScanAggregation::Max {
+                    AAggExpr::Max {
+                        input: e,
+                        propagate_nans: false,
+                    } => ScanAggregation::Max {
                         column: (*aexpr_to_leaf_names(*e, expr_arena).pop().unwrap()).to_string(),
                         alias,
                     },
@@ -272,7 +279,8 @@ impl PhysicalPlanner {
                 let phys_aggs =
                     self.create_physical_expressions(&aggs, Context::Aggregation, expr_arena)?;
 
-                let slice = options.slice;
+                let _slice = options.slice;
+                #[cfg(feature = "dynamic_groupby")]
                 if let Some(options) = options.dynamic {
                     return Ok(Box::new(executors::GroupByDynamicExec {
                         input,
@@ -280,10 +288,11 @@ impl PhysicalPlanner {
                         aggs: phys_aggs,
                         options,
                         input_schema,
-                        slice,
+                        slice: _slice,
                     }));
                 }
 
+                #[cfg(feature = "dynamic_groupby")]
                 if let Some(options) = options.rolling {
                     return Ok(Box::new(executors::GroupByRollingExec {
                         input,
@@ -291,7 +300,7 @@ impl PhysicalPlanner {
                         aggs: phys_aggs,
                         options,
                         input_schema,
-                        slice,
+                        slice: _slice,
                     }));
                 }
 
@@ -364,8 +373,8 @@ impl PhysicalPlanner {
                                     Agg(agg_e) => {
                                         matches!(
                                             agg_e,
-                                            AAggExpr::Min(_)
-                                                | AAggExpr::Max(_)
+                                            AAggExpr::Min{..}
+                                                | AAggExpr::Max{..}
                                                 | AAggExpr::Sum(_)
                                                 | AAggExpr::Last(_)
                                                 | AAggExpr::First(_)
