@@ -120,7 +120,8 @@ class ExprDateTimeNameSpace:
             2001-01-01 23:00:00
             2001-01-02 00:00:00
         ]
-        >>> assert s.dt.truncate("1h") == s.dt.truncate(timedelta(hours=1))
+        >>> s.dt.truncate("1h").series_equal(s.dt.truncate(timedelta(hours=1)))
+        True
 
         """
         if offset is None:
@@ -145,7 +146,7 @@ class ExprDateTimeNameSpace:
         """
         Extract year from underlying Date representation.
 
-        Can be performed on Date and Datetime columns.
+        Applies to Date and Datetime columns.
 
         Returns the year number in the calendar date.
 
@@ -193,11 +194,27 @@ class ExprDateTimeNameSpace:
         """
         return pli.wrap_expr(self._pyexpr.year())
 
+    def iso_year(self) -> pli.Expr:
+        """
+        Extract ISO year from underlying Date representation.
+
+        Applies to Date and Datetime columns.
+
+        Returns the year number in the ISO standard.
+        This may not correspond with the calendar year.
+
+        Returns
+        -------
+        ISO Year as Int32
+
+        """
+        return pli.wrap_expr(self._pyexpr.iso_year())
+
     def quarter(self) -> pli.Expr:
         """
         Extract quarter from underlying Date representation.
 
-        Can be performed on Date and Datetime columns.
+        Applies to Date and Datetime columns.
 
         Returns the quarter ranging from 1 to 4.
 
@@ -245,7 +262,7 @@ class ExprDateTimeNameSpace:
         """
         Extract month from underlying Date representation.
 
-        Can be performed on Date and Datetime columns.
+        Applies to Date and Datetime columns.
 
         Returns the month number starting from 1.
         The return value ranges from 1 to 12.
@@ -294,7 +311,7 @@ class ExprDateTimeNameSpace:
         """
         Extract the week from the underlying Date representation.
 
-        Can be performed on Date and Datetime columns.
+        Applies to Date and Datetime columns.
 
         Returns the ISO week number starting from 1.
         The return value ranges from 1 to 53. (The last week of year differs by years.)
@@ -343,7 +360,7 @@ class ExprDateTimeNameSpace:
         """
         Extract the week day from the underlying Date representation.
 
-        Can be performed on Date and Datetime columns.
+        Applies to Date and Datetime columns.
 
         Returns the weekday number where monday = 0 and sunday = 6
 
@@ -397,7 +414,7 @@ class ExprDateTimeNameSpace:
         """
         Extract day from underlying Date representation.
 
-        Can be performed on Date and Datetime columns.
+        Applies to Date and Datetime columns.
 
         Returns the day of month starting from 1.
         The return value ranges from 1 to 31. (The last day of month differs by months.)
@@ -452,7 +469,7 @@ class ExprDateTimeNameSpace:
         """
         Extract ordinal day from underlying Date representation.
 
-        Can be performed on Date and Datetime columns.
+        Applies to Date and Datetime columns.
 
         Returns the day of year starting from 1.
         The return value ranges from 1 to 366. (The last day of year differs by years.)
@@ -507,7 +524,7 @@ class ExprDateTimeNameSpace:
         """
         Extract hour from underlying DateTime representation.
 
-        Can be performed on Datetime columns.
+        Applies to Datetime columns.
 
         Returns the hour number from 0 to 23.
 
@@ -555,7 +572,7 @@ class ExprDateTimeNameSpace:
         """
         Extract minutes from underlying DateTime representation.
 
-        Can be performed on Datetime columns.
+        Applies to Datetime columns.
 
         Returns the minute number from 0 to 59.
 
@@ -605,7 +622,7 @@ class ExprDateTimeNameSpace:
         """
         Extract seconds from underlying DateTime representation.
 
-        Can be performed on Datetime columns.
+        Applies to Datetime columns.
 
         Returns the integer second number from 0 to 59, or a floating
         point number from 0 < 60 if ``fractional=True`` that includes
@@ -668,6 +685,39 @@ class ExprDateTimeNameSpace:
         │ 5.765431 │
         └──────────┘
 
+        >>> from datetime import timedelta, datetime
+        >>> start = datetime(2001, 1, 1)
+        >>> stop = datetime(2001, 1, 1, 0, 0, 4)
+        >>> df = pl.DataFrame(
+        ...     {"date": pl.date_range(start, stop, timedelta(seconds=2))}
+        ... )
+        >>> df
+        shape: (3, 1)
+        ┌─────────────────────┐
+        │ date                │
+        │ ---                 │
+        │ datetime[μs]        │
+        ╞═════════════════════╡
+        │ 2001-01-01 00:00:00 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:00:02 │
+        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
+        │ 2001-01-01 00:00:04 │
+        └─────────────────────┘
+        >>> df.select(pl.col("date").dt.second())
+        shape: (3, 1)
+        ┌──────┐
+        │ date │
+        │ ---  │
+        │ u32  │
+        ╞══════╡
+        │ 0    │
+        ├╌╌╌╌╌╌┤
+        │ 2    │
+        ├╌╌╌╌╌╌┤
+        │ 4    │
+        └──────┘
+
         """
         sec = pli.wrap_expr(self._pyexpr.second())
         return (
@@ -676,18 +726,41 @@ class ExprDateTimeNameSpace:
             else sec
         )
 
-    def nanosecond(self) -> pli.Expr:
+    def millisecond(self) -> pli.Expr:
         """
-        Extract seconds from underlying DateTime representation.
+        Extract milliseconds from underlying DateTime representation.
 
-        Can be performed on Datetime columns.
-
-        Returns the number of nanoseconds since the whole non-leap second.
-        The range from 1,000,000,000 to 1,999,999,999 represents the leap second.
+        Applies to Datetime columns.
 
         Returns
         -------
-        Nanosecond as UInt32
+        Milliseconds as UInt32
+
+        """
+        return pli.wrap_expr(self._pyexpr.millisecond())
+
+    def microsecond(self) -> pli.Expr:
+        """
+        Extract microseconds from underlying DateTime representation.
+
+        Applies to Datetime columns.
+
+        Returns
+        -------
+        Microseconds as UInt32
+
+        """
+        return pli.wrap_expr(self._pyexpr.microsecond())
+
+    def nanosecond(self) -> pli.Expr:
+        """
+        Extract nanoseconds from underlying DateTime representation.
+
+        Applies to Datetime columns.
+
+        Returns
+        -------
+        Nanoseconds as UInt32
 
         """
         return pli.wrap_expr(self._pyexpr.nanosecond())
@@ -906,6 +979,21 @@ class ExprDateTimeNameSpace:
         """
         return pli.wrap_expr(self._pyexpr.dt_with_time_zone(tz))
 
+    def cast_time_zone(self, tz: str) -> pli.Expr:
+        """
+        Cast time zone for a Series of type Datetime.
+
+        Different from ``with_time_zone``, this will also modify
+        the underlying timestamp,
+
+        Parameters
+        ----------
+        tz
+            Time zone for the `Datetime` Series.
+
+        """
+        return pli.wrap_expr(self._pyexpr.dt_cast_time_zone(tz))
+
     def days(self) -> pli.Expr:
         """
         Extract the days from a Duration type.
