@@ -18,7 +18,6 @@ use polars_core::prelude::QuantileInterpolOptions;
 use polars_core::utils::arrow::compute::cast::CastOptions;
 use polars_core::utils::try_get_supertype;
 use polars_lazy::frame::pivot::{pivot, pivot_stable};
-use pyo3::exceptions::PyRuntimeError;
 use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyList, PyTuple};
 
@@ -339,6 +338,18 @@ impl PyDataFrame {
         }
     }
 
+    #[staticmethod]
+    #[cfg(feature = "json")]
+    pub fn read_ndjson(py_f: &PyAny) -> PyResult<Self> {
+        let mmap_bytes_r = get_mmap_bytes_reader(py_f)?;
+
+        let out = JsonReader::new(mmap_bytes_r)
+            .with_json_format(JsonFormat::JsonLines)
+            .finish()
+            .map_err(|e| PyPolarsErr::Other(format!("{:?}", e)))?;
+        Ok(out.into())
+    }
+
     #[cfg(feature = "json")]
     pub fn write_json(
         &mut self,
@@ -366,6 +377,18 @@ impl PyDataFrame {
         Ok(())
     }
 
+    #[cfg(feature = "json")]
+    pub fn write_ndjson(&mut self, py_f: PyObject) -> PyResult<()> {
+        let file = BufWriter::new(get_file_like(py_f, true)?);
+
+        let r = JsonWriter::new(file)
+            .with_json_format(JsonFormat::JsonLines)
+            .finish(&mut self.df);
+
+        r.map_err(|e| PyPolarsErr::Other(format!("{:?}", e)))?;
+        Ok(())
+    }
+
     #[staticmethod]
     pub fn from_arrow_record_batches(rb: Vec<&PyAny>) -> PyResult<Self> {
         let df = arrow_interop::to_rust::to_rust_df(&rb)?;
@@ -431,7 +454,7 @@ impl PyDataFrame {
         float_precision: Option<usize>,
         null_value: Option<String>,
     ) -> PyResult<()> {
-        let null = null_value.unwrap_or(String::new());
+        let null = null_value.unwrap_or_default();
 
         if let Ok(s) = py_f.extract::<&str>(py) {
             let f = std::fs::File::create(s).unwrap();
@@ -762,21 +785,6 @@ impl PyDataFrame {
         format!("{:?}", self.df)
     }
 
-    pub fn join(
-        &self,
-        other: &PyDataFrame,
-        left_on: Vec<&str>,
-        right_on: Vec<&str>,
-        how: Wrap<JoinType>,
-        suffix: String,
-    ) -> PyResult<Self> {
-        let df = self
-            .df
-            .join(&other.df, left_on, right_on, how.0, Some(suffix))
-            .map_err(PyPolarsErr::from)?;
-        Ok(PyDataFrame::new(df))
-    }
-
     pub fn get_columns(&self) -> Vec<PySeries> {
         let cols = self.df.get_columns().clone();
         to_pyseries_collection(cols)
@@ -795,12 +803,6 @@ impl PyDataFrame {
         Ok(())
     }
 
-    pub fn with_column(&mut self, s: PySeries) -> PyResult<Self> {
-        let mut df = self.df.clone();
-        df.with_column(s.series).map_err(PyPolarsErr::from)?;
-        Ok(df.into())
-    }
-
     /// Get datatypes
     pub fn dtypes(&self, py: Python) -> PyObject {
         let iter = self
@@ -894,16 +896,6 @@ impl PyDataFrame {
         Ok(PyDataFrame::new(df))
     }
 
-    pub fn filter(&self, mask: &PySeries) -> PyResult<Self> {
-        let filter_series = &mask.series;
-        if let Ok(ca) = filter_series.bool() {
-            let df = self.df.filter(ca).map_err(PyPolarsErr::from)?;
-            Ok(PyDataFrame::new(df))
-        } else {
-            Err(PyRuntimeError::new_err("Expected a boolean mask"))
-        }
-    }
-
     pub fn take(&self, indices: Wrap<Vec<IdxSize>>) -> PyResult<Self> {
         let indices = indices.0;
         let indices = IdxCa::from_vec("", indices);
@@ -938,11 +930,6 @@ impl PyDataFrame {
         Ok(())
     }
 
-    pub fn rename(&mut self, column: &str, new_col: &str) -> PyResult<()> {
-        self.df.rename(column, new_col).map_err(PyPolarsErr::from)?;
-        Ok(())
-    }
-
     pub fn replace_at_idx(&mut self, index: usize, new_col: PySeries) -> PyResult<()> {
         self.df
             .replace_at_idx(index, new_col.series)
@@ -1048,6 +1035,7 @@ impl PyDataFrame {
         Ok(df.into())
     }
 
+    #[allow(deprecated)]
     pub fn groupby_quantile(
         &self,
         by: Vec<&str>,
@@ -1342,6 +1330,7 @@ impl PyDataFrame {
     }
 }
 
+#[allow(deprecated)]
 fn finish_groupby(gb: GroupBy, agg: &str) -> PyResult<PyDataFrame> {
     Python::with_gil(|py| {
         let df = py.allow_threads(|| match agg {
