@@ -3,6 +3,8 @@
 # ------------------------------------------------
 from __future__ import annotations
 
+from typing import Any
+
 from hypothesis import given, settings
 from hypothesis.strategies import sampled_from
 
@@ -14,7 +16,7 @@ TEMPORAL_DTYPES = [pl.Datetime, pl.Date, pl.Time, pl.Duration]
 
 
 @given(df=dataframes(), lf=dataframes(lazy=True), srs=series())
-@settings(max_examples=10)
+@settings(max_examples=5)
 def test_strategy_classes(df: pl.DataFrame, lf: pl.LazyFrame, srs: pl.Series) -> None:
     assert isinstance(df, pl.DataFrame)
     assert isinstance(lf, pl.LazyFrame)
@@ -22,13 +24,16 @@ def test_strategy_classes(df: pl.DataFrame, lf: pl.LazyFrame, srs: pl.Series) ->
 
 
 @given(
-    df1=dataframes(cols=5, size=5),
-    df2=dataframes(min_cols=2, max_cols=5, min_size=3, max_size=8),
-    s1=series(size=5),
-    s2=series(min_size=3, max_size=8, name="col"),
+    s1=series(dtype=pl.Boolean, size=5),
+    s2=series(dtype=pl.Boolean, min_size=3, max_size=8, name="col"),
+    df1=dataframes(allowed_dtypes=[pl.Boolean], cols=5, size=5),
+    df2=dataframes(
+        allowed_dtypes=[pl.Boolean], min_cols=2, max_cols=5, min_size=3, max_size=8
+    ),
 )
+@settings(max_examples=50)
 def test_strategy_shape(
-    df1: pl.DataFrame, df2: pl.DataFrame, s1: pl.Series, s2: pl.Series
+    s1: pl.Series, s2: pl.Series, df1: pl.DataFrame, df2: pl.DataFrame
 ) -> None:
     assert df1.shape == (5, 5)
     assert df1.columns == ["col0", "col1", "col2", "col3", "col4"]
@@ -80,13 +85,14 @@ def test_strategy_frame_columns(lf: pl.LazyFrame) -> None:
 
 
 @given(
-    df=dataframes(allowed_dtypes=TEMPORAL_DTYPES, max_size=1),
-    lf=dataframes(excluded_dtypes=TEMPORAL_DTYPES, max_size=1, lazy=True),
+    df=dataframes(allowed_dtypes=TEMPORAL_DTYPES, max_size=1, max_cols=5),
+    lf=dataframes(excluded_dtypes=TEMPORAL_DTYPES, max_size=1, max_cols=5, lazy=True),
     s1=series(max_size=1),
     s2=series(dtype=pl.Boolean, max_size=1),
     s3=series(allowed_dtypes=TEMPORAL_DTYPES, max_size=1),
     s4=series(excluded_dtypes=TEMPORAL_DTYPES, max_size=1),
 )
+@settings(max_examples=50)
 def test_strategy_dtypes(
     df: pl.DataFrame,
     lf: pl.LazyFrame,
@@ -139,3 +145,47 @@ def test_strategy_null_probability(
     nulls_col0, nulls_colx = df3.null_count().rows()[0]
     assert nulls_col0 > nulls_colx
     assert nulls_col0 == 50
+
+
+@given(
+    df1=dataframes(chunked=False, min_size=1),
+    df2=dataframes(chunked=True, min_size=1),
+    s1=series(chunked=False, min_size=1),
+    s2=series(chunked=True, min_size=1),
+)
+@settings(max_examples=10)
+def test_chunking(
+    df1: pl.DataFrame,
+    df2: pl.DataFrame,
+    s1: pl.Series,
+    s2: pl.Series,
+) -> None:
+    assert df1.n_chunks() == 1
+    if len(df2) > 1:
+        assert df2.n_chunks("all") == [2] * len(df2.columns)
+
+    assert s1.n_chunks() == 1
+    if len(s2) > 1:
+        assert s2.n_chunks() > 1
+
+
+@given(
+    df=dataframes(
+        allowed_dtypes=[pl.Float32, pl.Float64], max_cols=4, allow_infinities=False
+    ),
+    s=series(dtype=pl.Float64, allow_infinities=False),
+)
+def test_infinities(
+    df: pl.DataFrame,
+    s: pl.Series,
+) -> None:
+    from math import isfinite
+
+    def finite_float(value: Any) -> bool:
+        if isinstance(value, float):
+            return isfinite(value)
+        return False
+
+    assert all(finite_float(val) for val in s.to_list())
+    for col in df.columns:
+        assert all(finite_float(val) for val in df[col].to_list())
