@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import math
-from datetime import date, datetime, time
+from datetime import date, datetime, time, timedelta
 from typing import TYPE_CHECKING, Any, cast
 
 import numpy as np
@@ -10,8 +10,22 @@ import pyarrow as pa
 import pytest
 
 import polars as pl
-from polars.datatypes import Date, Datetime, Float64, Int32, Int64, Time, UInt32, UInt64
-from polars.testing import assert_series_equal, verify_series_and_expr_api
+from polars.datatypes import (
+    Date,
+    Datetime,
+    Field,
+    Float64,
+    Int32,
+    Int64,
+    Time,
+    UInt32,
+    UInt64,
+)
+from polars.testing import (
+    assert_frame_equal,
+    assert_series_equal,
+    verify_series_and_expr_api,
+)
 
 if TYPE_CHECKING:
     from polars.internals.type_aliases import TimeUnit
@@ -100,6 +114,53 @@ def test_init_inputs(monkeypatch: Any) -> None:
         pl.DataFrame(np.array([1, 2, 3]), columns=["a"])
 
 
+def test_init_dataclass_namedtuple() -> None:
+    from dataclasses import dataclass
+    from typing import NamedTuple
+
+    @dataclass
+    class TeaShipmentDC:
+        exporter: str
+        importer: str
+        product: str
+        tonnes: int | None
+
+    class TeaShipmentNT(NamedTuple):
+        exporter: str
+        importer: str
+        product: str
+        tonnes: None | int
+
+    for Tea in (TeaShipmentDC, TeaShipmentNT):
+        t0 = Tea(exporter="Sri Lanka", importer="USA", product="Ceylon", tonnes=10)
+        t1 = Tea(exporter="India", importer="UK", product="Darjeeling", tonnes=25)
+
+        s = pl.Series("t", [t0, t1])
+
+        assert isinstance(s, pl.Series)
+        assert s.dtype.fields == [  # type: ignore[attr-defined]
+            Field("exporter", pl.Utf8),
+            Field("importer", pl.Utf8),
+            Field("product", pl.Utf8),
+            Field("tonnes", pl.Int64),
+        ]
+        assert s.to_list() == [
+            {
+                "exporter": "Sri Lanka",
+                "importer": "USA",
+                "product": "Ceylon",
+                "tonnes": 10,
+            },
+            {
+                "exporter": "India",
+                "importer": "UK",
+                "product": "Darjeeling",
+                "tonnes": 25,
+            },
+        ]
+        assert_frame_equal(s.to_frame(), pl.DataFrame({"t": [t0, t1]}))
+
+
 def test_concat() -> None:
     s = pl.Series("a", [2, 1, 3])
 
@@ -457,6 +518,10 @@ def test_ufunc() -> None:
         cast(pl.Series, np.power(s_uint8, 2.0)),
         pl.Series("a", [1.0, 4.0, 9.0, 16.0], dtype=pl.Float64),
     )
+    assert_series_equal(
+        cast(pl.Series, np.power(s_uint8, 2, dtype=np.uint16)),
+        pl.Series("a", [1, 4, 9, 16], dtype=pl.UInt16),
+    )
 
     s_int8 = pl.Series("a", [1, -2, 3, -4], dtype=pl.Int8)
     assert_series_equal(
@@ -467,6 +532,10 @@ def test_ufunc() -> None:
         cast(pl.Series, np.power(s_int8, 2.0)),
         pl.Series("a", [1.0, 4.0, 9.0, 16.0], dtype=pl.Float64),
     )
+    assert_series_equal(
+        cast(pl.Series, np.power(s_int8, 2, dtype=np.int16)),
+        pl.Series("a", [1, 4, 9, 16], dtype=pl.Int16),
+    )
 
     s_uint32 = pl.Series("a", [1, 2, 3, 4], dtype=pl.UInt32)
     assert_series_equal(
@@ -641,6 +710,39 @@ def test_fill_null() -> None:
     assert a.fill_null(strategy="backward").to_list() == [0.0, 1.0, 2.0, 2.0, 3.0, 3.0]
     assert a.fill_null(strategy="mean").to_list() == [0.0, 1.0, 1.5, 2.0, 1.5, 3.0]
 
+    df = pl.DataFrame(
+        [
+            pl.Series("i32", [1, 2, None], dtype=pl.Int32),
+            pl.Series("i64", [1, 2, None], dtype=pl.Int64),
+            pl.Series("f32", [1, 2, None], dtype=pl.Float32),
+            pl.Series("cat", ["a", "b", None], dtype=pl.Categorical),
+            pl.Series("str", ["a", "b", None], dtype=pl.Utf8),
+            pl.Series("bool", [True, True, None], dtype=pl.Boolean),
+        ]
+    )
+
+    assert df.fill_null(0, matches_supertype=False).fill_null("bar").fill_null(
+        False
+    ).to_dict(False) == {
+        "i32": [1, 2, None],
+        "i64": [1, 2, 0],
+        "f32": [1.0, 2.0, None],
+        "cat": ["a", "b", "bar"],
+        "str": ["a", "b", "bar"],
+        "bool": [True, True, False],
+    }
+
+    assert df.fill_null(0, matches_supertype=True).fill_null("bar").fill_null(
+        False
+    ).to_dict(False) == {
+        "i32": [1, 2, 0],
+        "i64": [1, 2, 0],
+        "f32": [1.0, 2.0, 0.0],
+        "cat": ["a", "b", "bar"],
+        "str": ["a", "b", "bar"],
+        "bool": [True, True, False],
+    }
+
 
 def test_fill_nan() -> None:
     nan = float("nan")
@@ -1247,6 +1349,7 @@ def test_from_sequences(monkeypatch: Any) -> None:
 
 def test_comparisons_int_series_to_float() -> None:
     srs_int = pl.Series([1, 2, 3, 4])
+
     assert_series_equal(srs_int - 1.0, pl.Series([0.0, 1.0, 2.0, 3.0]))
     assert_series_equal(srs_int + 1.0, pl.Series([2.0, 3.0, 4.0, 5.0]))
     assert_series_equal(srs_int * 2.0, pl.Series([2.0, 4.0, 6.0, 8.0]))
@@ -1254,6 +1357,9 @@ def test_comparisons_int_series_to_float() -> None:
     assert_series_equal(srs_int % 2.0, pl.Series([1.0, 0.0, 1.0, 0.0]))
     assert_series_equal(4.0 % srs_int, pl.Series([0.0, 0.0, 1.0, 0.0]))
 
+    assert_series_equal(srs_int - pl.lit(1.0), pl.Series([0.0, 1.0, 2.0, 3.0]))
+    assert_series_equal(srs_int + pl.lit(1.0), pl.Series([2.0, 3.0, 4.0, 5.0]))
+
     assert_series_equal(srs_int // 2.0, pl.Series([0.0, 1.0, 1.0, 2.0]))
     assert_series_equal(srs_int < 3.0, pl.Series([True, True, False, False]))
     assert_series_equal(srs_int <= 3.0, pl.Series([True, True, True, False]))
@@ -1265,6 +1371,7 @@ def test_comparisons_int_series_to_float() -> None:
 
 def test_comparisons_float_series_to_int() -> None:
     srs_float = pl.Series([1.0, 2.0, 3.0, 4.0])
+
     assert_series_equal(srs_float - 1, pl.Series([0.0, 1.0, 2.0, 3.0]))
     assert_series_equal(srs_float + 1, pl.Series([2.0, 3.0, 4.0, 5.0]))
     assert_series_equal(srs_float * 2, pl.Series([2.0, 4.0, 6.0, 8.0]))
@@ -1272,6 +1379,9 @@ def test_comparisons_float_series_to_int() -> None:
     assert_series_equal(srs_float % 2, pl.Series([1.0, 0.0, 1.0, 0.0]))
     assert_series_equal(4 % srs_float, pl.Series([0.0, 0.0, 1.0, 0.0]))
 
+    assert_series_equal(srs_float - pl.lit(1), pl.Series([0.0, 1.0, 2.0, 3.0]))
+    assert_series_equal(srs_float + pl.lit(1), pl.Series([2.0, 3.0, 4.0, 5.0]))
+
     assert_series_equal(srs_float // 2, pl.Series([0.0, 1.0, 1.0, 2.0]))
     assert_series_equal(srs_float < 3, pl.Series([True, True, False, False]))
     assert_series_equal(srs_float <= 3, pl.Series([True, True, True, False]))
@@ -1871,6 +1981,32 @@ def test_ewm_std_var() -> None:
     assert np.allclose(var, std**2, rtol=1e-16)
 
 
+def test_ewm_param_validation() -> None:
+    s = pl.Series("values", range(10))
+
+    with pytest.raises(ValueError, match="mutually exclusive"):
+        s.ewm_std(com=0.5, alpha=0.5)
+
+    with pytest.raises(ValueError, match="mutually exclusive"):
+        s.ewm_mean(span=1.5, half_life=0.75)
+
+    with pytest.raises(ValueError, match="mutually exclusive"):
+        s.ewm_var(alpha=0.5, span=1.5)
+
+    with pytest.raises(ValueError, match="Require 'com' >= 0"):
+        s.ewm_std(com=-0.5)
+
+    with pytest.raises(ValueError, match="Require 'span' >= 1"):
+        s.ewm_mean(span=0.5)
+
+    with pytest.raises(ValueError, match="Require 'half_life' > 0"):
+        s.ewm_var(half_life=0)
+
+    for alpha in (-0.5, -0.0000001, 0.0, 1.0000001, 1.5):
+        with pytest.raises(ValueError, match="Require 0 < 'alpha' <= 1"):
+            s.ewm_std(alpha=alpha)
+
+
 def test_extend_constant() -> None:
     a = pl.Series("a", [1, 2, 3])
     expected = pl.Series("a", [1, 2, 3, 1, 1, 1])
@@ -1922,6 +2058,23 @@ def test_ceil() -> None:
     verify_series_and_expr_api(a, expected, "ceil")
 
 
+def test_duration_arithmetic() -> None:
+    # apply some basic duration math to series
+    s = pl.Series([datetime(2022, 1, 1, 10, 20, 30), datetime(2022, 1, 2, 20, 40, 50)])
+    d1 = pl.duration(days=5, microseconds=123456)
+    d2 = timedelta(days=5, microseconds=123456)
+
+    expected_values = [
+        datetime(2022, 1, 6, 10, 20, 30, 123456),
+        datetime(2022, 1, 7, 20, 40, 50, 123456),
+    ]
+    for d in (d1, d2):
+        df1 = pl.select((s + d).alias("d_offset"))
+        df2 = pl.select((d + s).alias("d_offset"))
+        assert df1["d_offset"].to_list() == expected_values
+        assert df1["d_offset"].series_equal(df2["d_offset"])
+
+
 def test_duration_extract_times() -> None:
     a = pl.Series("a", [datetime(2021, 1, 1)])
     b = pl.Series("b", [datetime(2021, 1, 2)])
@@ -2106,6 +2259,4 @@ def test_repr() -> None:
 
 def test_builtin_abs() -> None:
     s = pl.Series("s", [-1, 0, 1, None])
-    a = abs(s)
-
-    assert a.to_list() == [1, 0, 1, None]
+    assert abs(s).to_list() == [1, 0, 1, None]
